@@ -29,6 +29,26 @@ or "no" or "false".
 The cleaned and lowercased header. Directives with underscores are
 ignored.
 
+=head2 title
+
+Verbatim header field
+
+=head2 subtitle
+
+Verbatim header field
+
+=head2 listtitle
+
+Verbatim header field
+
+=head2 listing_title
+
+Return listtitle if set, title otherwise.
+
+=head2 author
+
+Verbatim header field
+
 =head2 language
 
 Defaults to en if not present.
@@ -55,6 +75,12 @@ Same as C<topics>, but returns a plain list of HTML formatted topics.
 
 Same as C<authors>, but returns a plain list of HTML formatted authors.
 
+=head2 tex_metadata
+
+Return an hashref with the following keys: C<title> C<author>
+C<subject> C<keywords> with the values LaTeX escaped, mapping to the
+relevant headers values for setting PDF metadata.
+
 =head1 INTERNALS
 
 =head2 BUILDARGS
@@ -85,10 +111,25 @@ sub BUILDARGS {
         }
         $lowered{$lck} = $directives->{$k};
     }
-
-    return { header => { %lowered } };
+    my %args = (header => { %lowered });
+    foreach my $f (qw/title listtitle subtitle author/) {
+        if (exists $lowered{$f} and
+            defined $lowered{$f} and
+            $lowered{$f} =~ m/\w/) {
+            $args{$f} = $lowered{$f};
+        }
+        else {
+            $args{$f} = '';
+        }
+    }
+    return \%args;
 }
 
+has title => (is => 'ro', isa => Str, required => 1);
+has subtitle => (is => 'ro', isa => Str, required => 1);
+has listtitle => (is => 'ro', isa => Str, required => 1);
+has author => (is => 'ro', isa => Str, required => 1);
+
 has header => (is => 'ro', isa => HashRef[Str]);
 
 has language => (is => 'lazy', isa => Str);
@@ -224,6 +265,30 @@ sub _html_strings {
     return @out;
 }
 
+sub listing_title {
+    my $self = shift;
+    if (length($self->listtitle)) {
+        return $self->listtitle;
+    }
+    else {
+        return $self->title;
+    }
+}
+
+sub tex_metadata {
+    my $self = shift;
+    my %out = (
+               title => $self->listing_title,
+               author => (scalar(@{$self->authors}) ? join('; ', @{$self->authors}) : $self->author),
+               subject => $self->subtitle,
+               keywords => (scalar(@{$self->topics}) ? join('; ', @{$self->topics}) : ''),
+              );
+    foreach my $k (keys %out) {
+        $out{$k} = muse_format_line(ltx => $out{$k});
+    }
+    return \%out;
+}
+
 sub _parse_topic_or_author {
     my ($self, $field) = @_;
     my $header = $self->header;
