@@ -770,6 +770,17 @@ sub latex {
 \author{[% doc.header_as_latex.author %]}
 \subtitle{[% doc.header_as_latex.subtitle %]}
 
+[% IF tex_metadata %]
+% https://groups.google.com/d/topic/comp.text.tex/6fYmcVMbSbQ/discussion
+\hypersetup{%
+pdfencoding=auto,
+pdftitle={[% tex_metadata.title %]},%
+pdfauthor={[% tex_metadata.author %]},%
+pdfsubject={[% tex_metadata.subject %]},%
+pdfkeywords={[% tex_metadata.keywords %]}%
+}
+[% END %]
+
 \begin{document}
 [% IF doc.hyphenation %]
 \hyphenation{ [% doc.hyphenation %] }
